==> haskell-cryptonite-conduit-0.2.0-27-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-cryptonite-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cryptonite-conduit
version: 0.2.0
id: cryptonite-conduit-0.2.0-9qdCvM8BVWo5Yi8MYohyh2
key: cryptonite-conduit-0.2.0-9qdCvM8BVWo5Yi8MYohyh2
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: vincent@snarc.org
stability: experimental
homepage: https://github.com/haskell-crypto/cryptonite-conduit
synopsis: cryptonite conduit
description:
    Conduit bridge for cryptonite
    .
    For now only provide a conduit version for hash and hmac, but
    with contribution, this could provide cipher conduits too,
    and probably other things.
category: Cryptography, Conduit
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
exposed-modules:
    Crypto.MAC.HMAC.Conduit Crypto.Hash.Conduit
abi: 4093323941201c0f8a32c22467bea0f8
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/cryptonite-conduit-0.2.0
library-dirs: /usr/lib/ghc-8.0.1/site-local/cryptonite-conduit-0.2.0
data-dir: /usr/share/x86_64-linux-ghc-8.0.1/cryptonite-conduit-0.2.0
hs-libraries: HScryptonite-conduit-0.2.0-9qdCvM8BVWo5Yi8MYohyh2
depends:
    base-4.9.0.0 bytestring-0.10.8.1
    conduit-1.2.11-67QBPVFU7Mu9oEC9xc41Cq
    conduit-extra-1.1.16-848Xd70hoN45Ueua8FUxsp
    cryptonite-0.23-3GIkE0SDPeuXan48X60bd
    memory-0.14.6-300MPYpxHNH28XjtXjOwph
    resourcet-1.1.9-4wjmwiYhI4Y4ny0clYPjM8 transformers-0.5.2.0
haddock-interfaces: /usr/share/doc/haskell-cryptonite-conduit/html/cryptonite-conduit.haddock
haddock-html: /usr/share/doc/haskell-cryptonite-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cryptonite-conduit-0.2.0-28-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-cryptonite-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cryptonite-conduit
version: 0.2.0
id: cryptonite-conduit-0.2.0-K2GLmRAqJRXAdSQcmrMxC0
key: cryptonite-conduit-0.2.0-K2GLmRAqJRXAdSQcmrMxC0
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: vincent@snarc.org
stability: experimental
homepage: https://github.com/haskell-crypto/cryptonite-conduit
synopsis: cryptonite conduit
description:
    Conduit bridge for cryptonite
    .
    For now only provide a conduit version for hash and hmac, but
    with contribution, this could provide cipher conduits too,
    and probably other things.
category: Cryptography, Conduit
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
exposed-modules:
    Crypto.MAC.HMAC.Conduit Crypto.Hash.Conduit
abi: a7f4bc64b85d73960ba7eb0f1c684086
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/cryptonite-conduit-0.2.0
library-dirs: /usr/lib/ghc-8.0.1/site-local/cryptonite-conduit-0.2.0
data-dir: /usr/share/x86_64-linux-ghc-8.0.1/cryptonite-conduit-0.2.0
hs-libraries: HScryptonite-conduit-0.2.0-K2GLmRAqJRXAdSQcmrMxC0
depends:
    base-4.9.0.0 bytestring-0.10.8.1
    conduit-1.2.11-5u7YE5Ecuce5vjjIFEkula
    conduit-extra-1.1.16-64t3TdZCM2WFvJMJ9glban
    cryptonite-0.23-3GIkE0SDPeuXan48X60bd
    memory-0.14.6-300MPYpxHNH28XjtXjOwph
    resourcet-1.1.9-5Fmv0DqXfJBCCiUazI0vW3 transformers-0.5.2.0
haddock-interfaces: /usr/share/doc/haskell-cryptonite-conduit/html/cryptonite-conduit.haddock
haddock-html: /usr/share/doc/haskell-cryptonite-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
